intelmq.bots.experts.gethostbyname package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.gethostbyname package

## Submodules

## intelmq.bots.experts.gethostbyname.expert module

These are all possible gaierrors according to the source: http://www.castaglia.org/proftpd/doc/devel-guide/src/lib/glibc-gai_strerror.c.html

    # define EAI_BADFLAGS     -1    /* Invalid value for `ai_flags' field.  */
    # define EAI_NONAME       -2    /* NAME or SERVICE is unknown.  */
    # define EAI_AGAIN        -3    /* Temporary failure in name resolution.  */
    # define EAI_FAIL         -4    /* Non-recoverable failure in name res.  */
    # define EAI_NODATA       -5    /* No address associated with NAME.  */
    # define EAI_FAMILY       -6    /* `ai_family' not supported.  */
    # define EAI_SOCKTYPE     -7    /* `ai_socktype' not supported.  */
    # define EAI_SERVICE      -8    /* SERVICE not supported for `ai_socktype'.  */
    # define EAI_ADDRFAMILY   -9    /* Address family for NAME not supported.  */
    # define EAI_MEMORY       -10   /* Memory allocation failure.  */
    # define EAI_SYSTEM       -11   /* System error returned in `errno'.  */

We treat some of them as valid (ie record does not exist) and other as temporary or permanent failure (default).

intelmq.bots.experts.gethostbyname.expert.BOT

  alias of `intelmq.bots.experts.gethostbyname.expert.GethostbynameExpertBot`

class intelmq.bots.experts.gethostbyname.expert.GethostbynameExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Resolve the IP address for the FQDN

  fallback_to_url: bool = True
  gaierrors_to_ignore: Tuple[int] = ()
  init()
  overwrite: bool = False
  process()

## Module contents